/* Copyright (C) 2000/2001 sgop@users.sourceforge.net
   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING for details. */

#define P_TREE          0x00000001	// tree
#define P_GENERAL       0x00000002	// page general
#define P_SEARCH        0x0000001c
#define P_NSEARCH      0x00000004
#define P_RSEARCH      0x00000008
#define P_PINGS        0x00000010
#define P_TRANSFERS     0x00003fe0	// page transfer
#define P_D_LIMIT      0x00000020
#define P_U_LIMIT      0x00000040
#define P_D_ULIMIT     0x00000080
#define P_U_ULIMIT     0x00000100
#define P_U_REMOVE     0x00000200
#define P_D_REMOVE     0x00000400
#define P_RETRY        0x00000800
#define P_AUTORESUME   0x00001000
#define P_REST1        0x00002000
#define P_MIMETYPES     0x00004000	// page mimtypes
#define P_PATHS         0x00008000	// page paths
#define P_DOWNLOAD      0x00010000	// page download
#define P_SHARES        0x00020000	// page shares
#define P_APPEARANCE    0x001c0000	// page appearance
#define P_HIGHLIGHT    0x00040000
#define P_FRIENDS      0x00080000
#define P_ENEMIES      0x00100000
#define P_CHAT          0x07e00000	// chat appearance
#define P_IGNORE       0x00200000
#define P_SHOW_JOIN    0x00400000
#define P_TIMESTAMPS   0x00800000
#define P_SEND_IGNORE  0x01000000
#define P_PARSE_COLOR  0x02000000
#define P_TAB_STYLE    0x04000000
#define P_SCHEMES       0x08000000	// page schemes
#define P_ADVANCED      0x10000000	// page advanced
#define P_NETWORKS      0x20000000	
#define P_REJOIN       0x40000000	// page channels

#define P_NONE          0x00000000
#define P_ALL           0xfffffffe

void set_options_channels();
void setup_preferences(unsigned long flags);
void apply_preferences();
void preferences_goto(int section);
void clear_shared_folder();
void clear_suffixes();
GtkWidget *create_pipe_popup(int val);
GtkWidget *create_pipe2_popup(int val);

void on_dir_select343(gchar * dir);
